==> mapnik_3.0.0%2Bds.orig.tar.gz: mapnik-3.0.0/src/color_factory.cpp <==
/*****************************************************************************
 *
 * This file is part of Mapnik (c++ mapping toolkit)
 *
 * Copyright (C) 2015 Artem Pavlenko
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

// mapnik
#include <mapnik/color.hpp>
#include <mapnik/color_factory.hpp>
#include <mapnik/config_error.hpp>
#include <mapnik/css_color_grammar.hpp>

namespace mapnik {

color parse_color(std::string const& str)
{
    // TODO - early return for @color?
    static const css_color_grammar<std::string::const_iterator> g;
    color c;
    std::string::const_iterator first = str.begin();
    std::string::const_iterator last =  str.end();
    boost::spirit::ascii::space_type space;
    bool result = boost::spirit::qi::phrase_parse(first, last, g,
                                                  space,
                                                  c);
    if (result && (first == last))
    {
        return c;
    }
    else
    {
        throw config_error("Failed to a parse color: \"" + str + "\"");
    }
}

}

==> mapnik_3.0.12~rc3%2Bds.orig.tar.gz: mapnik-3.0.12-rc3/src/color_factory.cpp <==
/*****************************************************************************
 *
 * This file is part of Mapnik (c++ mapping toolkit)
 *
 * Copyright (C) 2015 Artem Pavlenko
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

// mapnik
#include <mapnik/color.hpp>
#include <mapnik/color_factory.hpp>
#include <mapnik/config_error.hpp>
#include <mapnik/css_color_grammar.hpp>

namespace mapnik {

color parse_color(std::string const& str)
{
    // TODO - early return for @color?
    static const css_color_grammar<std::string::const_iterator> g;
    color c;
    std::string::const_iterator first = str.begin();
    std::string::const_iterator last =  str.end();
    boost::spirit::ascii::space_type space;
    bool result = boost::spirit::qi::phrase_parse(first, last, g,
                                                  space,
                                                  c);
    if (result && (first == last))
    {
        return c;
    }
    else
    {
        throw config_error("Failed to parse color: \"" + str + "\"");
    }
}

}
